@@ -12,7 +12,7 @@ use Shell::Carapace;
 use String::ShellQuote;
 use JSON::MaybeXS;
 
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 
 =head1 NAME
 
@@ -44,6 +44,7 @@ Chef::Knife::Cmd - A small wrapper around the Chef 'knife' command line utility
     $knife->node->create($node, %options);
     $knife->node->delete($node, %options);
     $knife->node->flip($node, $environment, %options);
+    $knife->node->from->file($file, %options);
     $knife->node->run_list->add($node, \@entries, %options);
 
     # knife vault commands
@@ -193,11 +194,11 @@ sub run {
 
 =over 4
 
-=item Capture::Tiny::Extended
+=item L<Capture::Tiny::Extended>
 
-=item Capture::Tiny
+=item L<Capture::Tiny>
 
-=item IPC::System::Simple
+=item L<IPC::System::Simple>
 
 =back
 
